Discover Packages
github.com/moooyo/VirtualJudge
tools
package
Version:
v0.0.0-...-08a50c5
Opens a new window with list of versions in this module.
Published: Dec 23, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
const (
OK Err = 0
PostDataInvalid Err = 1001
ConnectOJError Err = 2001
)
type GlobalConfig struct {
WebConfig Web `yaml:"web"`
MysqlConfig Mysql `yaml:"mysql"`
}
type Mysql struct {
Address string `yaml:"address"`
Port int `yaml:"port"`
DB string `yaml:"database"`
User string `yaml:"username"`
Password string `yaml:"password"`
}
type Web struct {
Address string `yaml:"address"`
Port int `yaml:"port"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.